@extends($activeTemplate . 'layouts.app')
@section('app')
    @php
        $policyPages = getContent('policy_pages.element', orderById: true);
        $register = getContent('register.content', true);
        $placeholder = 'Captcha';
    @endphp

    <section class="account">
        <span class="account__shape"><img
                src="{{ getImage('assets/images/frontend/register/' . @$register->data_values->shape_one, '475x270') }}"
                alt="@lang('Image')"></span>
        <span class="account__shape two"><img
                src="{{ getImage('assets/images/frontend/register/' . @$register->data_values->shape_two, '380x220') }}"
                alt="@lang('Image')"></span>
        <div class="account__inner">
            <div class="account__left">
                <div class="top">
                    <a class="navbar-brand logo" href="{{ route('home') }}"><img src="{{ siteLogo('dark') }}"
                            alt="@lang('Image')"></a>
                    <p class="have-account d-sm-block d-none">@lang('Already have an account?') <a href="{{ route('user.login') }}"
                            class="have-account__link text--base">@lang('Login')</a></p>
                </div>
                <div class="account__content">
                    <form action="{{ route('user.register') }}" method="POST" class="account__form verify-gcaptcha">
                        @csrf
                        <div class="account__form-heading text-center">
                            <h2 class="title">{{ __(@$register->data_values->heading) }}</h2>
                            <span class="tagline">{{ __(@$register->data_values->subheading) }}</span>
                        </div>
                        <div class="row">
                            <div class="col-sm-6">
                                <div class="form-group">
                                    <input type="text" class="form--control checkUser" name="username"
                                        placeholder="Username" value="{{ old('username') }}" required>
                                    <small class="text--danger usernameExist"></small>
                                </div>

                            </div>
                            <div class="col-sm-6">
                                <div class="form-group">
                                    <input type="text" class="form--control checkUser" name="email" placeholder="Email"
                                        value="{{ old('email') }}" required>
                                </div>
                            </div>
                            <div class="col-sm-6">
                                <div class="form-group">
                                    <select class="form--control select" id="country" name="country" required>
                                        @foreach ($countries as $key => $country)
                                            <option data-mobile_code="{{ $country->dial_code }}"
                                                value="{{ $key }}">
                                                {{ __($country->country) }}</option>
                                        @endforeach
                                    </select>
                                </div>
                            </div>

                            <div class="col-sm-6">
                                <div class="form-group">
                                    <div class="input-group">
                                        <span class="input-group-text mobile-code "></span>
                                        <input class="form-control form--control checkUser" type="number" name="mobile"
                                            value="{{ old('mobile') }}" placeholder="Mobile">
                                    </div>
                                    <small class="text-danger mobileExist"></small>
                                </div>
                            </div>

                            <div class="col-sm-6">
                                <div class="form-group">
                                    <div class="position-relative">
                                        <input id="your-password" type="password" placeholder="@lang('Password')"
                                            class="form--control @if ($general->secure_password) secure-password @endif"
                                            name="password" required>
                                        <span class="password-show-hide fas fa-eye toggle-password fa-eye-slash"
                                            id="#password"></span>
                                    </div>
                                </div>
                            </div>

                            <div class="col-sm-6">
                                <div class="form-group">
                                    <div class="position-relative">
                                        <input id="your-password2" placeholder="@lang('Confirm Password')"
                                            name="password_confirmation" type="password" class="form-control form--control">
                                        <span class="password-show-hide fas fa-eye toggle-password fa-eye-slash"
                                            id="#password_confirmation"></span>
                                    </div>
                                </div>
                            </div>
                            <x-captcha :placeholder="$placeholder" />

                            @if ($general->agree)
                                <div class="col-12">
                                    <div class="form-group">
                                        <input class="me-1" id="agree" name="agree" type="checkbox"
                                            @checked(old('agree')) required>
                                        <label for="agree">@lang('I agree with')</label>
                                        <span>
                                            @foreach ($policyPages as $policy)
                                                <a href="{{ route('policy.pages', [slug($policy->data_values->title), $policy->id]) }}"
                                                    target="_blank">{{ __($policy->data_values->title) }}</a>
                                                @if (!$loop->last)
                                                    ,
                                                @endif
                                            @endforeach
                                        </span>
                                    </div>
                                </div>
                            @endif

                            <div class="form-group mb-0">
                                <button type="submit" class="btn btn--base w-100">@lang('Submit')</button>
                                <p class="have-account d-sm-none d-block">@lang('Already have an account?') <a href="{{ route('user.login') }}" class="have-account__link text--base">@lang('Login')</a></p>
                            </div>

                        </div>
                    </form>
                </div>
            </div>

            <div class="account__right">
                <div class="account__thumb">
                    <img src="{{ getImage('assets/images/frontend/register/' . @$register->data_values->right_side_image, '800x840') }}"
                        alt="@lang('Image')">
                </div>
            </div>

        </div>

        <div class="modal fade" id="existModalCenter" tabindex="-1" role="dialog" aria-labelledby="existModalCenterTitle"
            aria-hidden="true">
            <div class="modal-dialog modal-dialog-centered" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="existModalLongTitle">@lang('You are with us')</h5>
                        <span type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                            <i class="las la-times"></i>
                        </span>
                    </div>
                    <div class="modal-body">
                        <h6 class="text-center mb-0">@lang('You already have an account please Login ')</h6>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-dark btn-sm"
                            data-bs-dismiss="modal">@lang('Close')</button>
                        <a href="{{ route('user.login') }}" class="btn btn--base btn-sm">@lang('Login')</a>
                    </div>
                </div>
            </div>
        </div>
    </section>

@endsection



@if ($general->secure_password)
    @push('script-lib')
        <script src="{{ asset('assets/global/js/secure_password.js') }}"></script>
    @endpush
@endif

@push('script')
    <script>
        "use strict";
        (function($) {
            @if ($mobileCode)
                $(`option[data-code={{ $mobileCode }}]`).attr('selected', '');
            @endif

            $('select[name=country]').change(function() {
                $('.mobile-code').text(`+${$('select[name=country] :selected').data('mobile_code')}`);
            }).change();


            $('.checkUser').on('focusout', function(e) {
                var url = '{{ route('user.checkUser') }}';
                var value = $(this).val();
                var token = '{{ csrf_token() }}';
                if ($(this).attr('name') == 'mobile') {
                    var mobile = `${$('.mobile-code').text().substr(1)}${value}`;
                    var data = {
                        mobile: mobile,
                        _token: token
                    }
                }
                if ($(this).attr('name') == 'email') {
                    var data = {
                        email: value,
                        _token: token
                    }
                }
                if ($(this).attr('name') == 'username') {
                    var data = {
                        username: value,
                        _token: token
                    }
                }

                $.post(url, data, function(response) {
                    if (response.data != false && response.type == 'email') {
                        $('#existModalCenter').modal('show');
                    } else if (response.data != false) {
                        $(`.${response.type}Exist`).text(`${response.type} already exist`);
                    } else {
                        $(`.${response.type}Exist`).text('');
                    }
                });
            });
        })(jQuery);
    </script>
@endpush
