@extends($activeTemplate . 'layouts.' . $layout)
@section('content')
    @if ($layout == 'frontend')
        <div class="container">
    @endif

    <div class="card custom--card">
        <div class="card-header gap-2 d-flex justify-content-between align-items-center flex-wrap">
            <h5 class="mb-0 d-flex align-items-center gap-2 flex-wrap">
                @php echo $myTicket->statusBadge; @endphp
                [@lang('Ticket')#{{ $myTicket->ticket }}] {{ $myTicket->subject }}
            </h5>
            @if ($myTicket->status != Status::TICKET_CLOSE && $myTicket->user)
                <button class="btn btn--danger close-button btn--sm confirmationBtn" data-question="@lang('Are you sure to close this ticket?')"
                        data-action="{{ route('ticket.close', $myTicket->id) }}" type="button"><i class="la la-times"></i>
                </button>
            @endif
        </div>
        <div class="card-body">
            <form method="post" action="{{ route('ticket.reply', $myTicket->id) }}" enctype="multipart/form-data">
                @csrf
                <div class="row justify-content-between">
                    <div class="col-md-12">
                        <label class="form--label">@lang('Your Reply')</label>
                        <div class="form--group">
                            <textarea class="form--control" name="message" rows="4">{{ old('message') }}</textarea>
                        </div>
                    </div>
                </div>
                <div class="text-end mb-2">
                    <a class="btn btn--base btn--sm addFile" href="javascript:void(0)"><i class="la la-plus"></i>
                        @lang('Add New')</a>
                </div>

                <div class="file-upload form--group">
                    <label class="form--label">@lang('Attachments') <small
                               class="text--danger">@lang('Max 5 files can be uploaded'). @lang('Maximum upload size is')
                            {{ ini_get('upload_max_filesize') }}</small></label>
                    <input type="file" name="attachments[]" id="inputAttachments"
                           class="form-control form--control mb-2">
                    <div id="fileUploadsContainer">

                    </div>
                    <p class="ticket-attachments-message text-muted">
                        @lang('Allowed File Extensions'): .@lang('jpg'), .@lang('jpeg'), .@lang('png'),
                        .@lang('pdf'), .@lang('doc'), .@lang('docx')
                    </p>
                </div>
                <button class="btn btn--base w-100" type="submit"> <i class="la la-reply"></i> @lang('Reply')</button>
            </form>
        </div>
    </div>

    <div class="mt-4">
        @foreach ($messages as $message)
            @if ($message->admin_id == 0)
                <div class="list support-list">
                    <div class="support-card">
                        <div class="support-card__head">
                            <h6 class="support-card__title">
                                {{ $message->ticket->name }}
                            </h6>
                            <span class="support-card__date">
                                <code class="xsm-text text-muted"><i class="far fa-clock"></i>
                                    {{ $message->created_at->format('l, dS F Y @ H:i') }}</code>
                            </span>
                        </div>
                        <div class="support-card__body">
                            <p class="support-card__body-text">
                                {{ $message->message }}
                            </p>
                            @if ($message->attachments->count() > 0)
                                <div class="mt-3">
                                    @foreach ($message->attachments as $k => $image)
                                        <div>
                                            <a class="me-3 support-card__file"
                                               href="{{ route('ticket.download', encrypt($image->id)) }}"><i
                                                   class="fa fa-file"></i> @lang('Attachment') {{ ++$k }} </a>
                                        </div>
                                    @endforeach
                                </div>
                            @endif
                        </div>
                    </div>
                </div>
            @else
                <div class="list support-list">
                    <div class="support-card admin-reply">
                        <div class="support-card__head">
                            <h6 class="support-card__title">{{ $message->admin->name }}</h6>
                            <span class="support-card__date">
                                <code class="xsm-text text-muted"><i class="far fa-clock"></i>
                                    {{ $message->created_at->format('l, dS F Y @ H:i') }}</code>
                            </span>
                        </div>
                        <div class="support-card__body">
                            <p class="support-card__body-text">
                                {{ $message->message }}
                            </p>
                            @if ($message->attachments->count() > 0)
                                <div class="mt-3">
                                    @foreach ($message->attachments as $k => $image)
                                        <a class="me-3 support-card__file"
                                           href="{{ route('ticket.download', encrypt($image->id)) }}"><i
                                               class="fa fa-file"></i> @lang('Attachment') {{ ++$k }} </a>
                                    @endforeach
                                </div>
                            @endif
                        </div>
                    </div>
                </div>
            @endif
        @endforeach
    </div>

    @if ($layout == 'frontend')
        </div>
    @endif
    <x-confirmation-modal btn="btn btn--base btn--sm" />
@endsection

@push('script')
    <script>
        (function($) {
            "use strict";
            var fileAdded = 0;
            $('.addFile').on('click', function() {
                if (fileAdded >= 4) {
                    notify('error', 'You\'ve added maximum number of file');
                    return false;
                }
                fileAdded++;
                $("#fileUploadsContainer").append(`
                    <div class="input-group my-3">
                        <input type="file" name="attachments[]" class="form-control form--control"  required="">
                        <button type="button" class="input-group-text btn-danger remove-btn"><i class="las la-times"></i></button>
                </div>
                `)
            });
            $(document).on('click', '.remove-btn', function() {
                fileAdded--;
                $(this).closest('.input-group').remove();
            });
            $('.btn--danger').addClass('text-white')
        })(jQuery);
    </script>
@endpush


@push('style')
    <style>
        /*---------------------------------------
                                                            2.44 Support Card
                                                        -----------------------------------------*/
        .support-card {
            border: 1px solid hsl(var(--base) / 0.4);
            border-radius: 5px;
            background: hsl(var(--white));
        }

        .admin-reply {
            border: 1px solid hsl(var(--danger) / 0.4);
        }

        .support-card__title {
            margin-top: 0;
            margin-bottom: 0.5rem;
        }

        @media screen and (min-width: 768px) {
            .support-card__title {
                margin-bottom: 0;
            }
        }

        .support-card__head {
            padding: 12px 15px;
            border-bottom: 1px solid hsl(var(--base) / 0.4);
        }

        .admin-reply .support-card__head {
            border-bottom: 1px solid hsl(var(--danger) / 0.4);
        }

        @media screen and (min-width: 768px) {
            .support-card__head {
                display: flex;
                justify-content: space-between;
            }
        }

        .support-card__date {
            display: block;
            line-height: 1;
        }

        .support-card__body {
            padding: 12px 15px;
        }

        .support-card__body-text {
            font-size: 14px;
            margin-bottom: 0;
            color: hsl(var(--dark) / 0.8);
        }

        .support-card__list {
            --gap: 0.5rem;
        }

        @media screen and (min-width: 768px) {
            .support-card__list {
                margin-top: 1rem;
            }
        }

        .support-card__file:hover {
            background: hsl(var(--base));
            color: hsl(var(--white));
        }

        /*---------------------------------------
                                                            2.45 Support List
                                                        -----------------------------------------*/
        .support-list {
            padding-top: 0.5rem;
            padding-bottom: 0.5rem;
        }

        .support-card__file {
            padding: 7px 10px;
            border: 1px solid hsl(var(--base) / 0.2);
            border-radius: 5px;
            font-size: 14px;
            line-height: 1;
            color: hsl(var(--base));
        }

        .admin-reply .support-card__file {
            border: 1px solid hsl(var(--danger) / 0.2)
        }
    </style>
@endpush
